/***************************************************************************
                               kmudfilter.h
                             -------------------
    begin                : Mon Oct 22 2001
    copyright            : (C) 2001 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMUDFILTER_H
#define KMUDFILTER_H

#include <qstring.h>

/**
  * This class represents an Input/Output Filter for data received from/sent to
  * the MUD. You can register this KmudFilter as an input/output filter in
  * @ref CMudStream. CMudStream then will call the filterInput/filterOutput
  * method every time it processes new input/output.
  * To use this KmudFilter inherit from it and reimplement the filter method(s).
  * Make sure that you return a QString (without the stuff you filter out).
  * If you don't filter out data from the incoming QString then return it
  * untouched. Otherwise the other filters called after you will receive
  * nothing.
  *
  * An example for an output filter is @ref KmudView which displays the output.
  * An example for an input filter is @ref CTelnet which sends the input to the
  * MUD.
  *
  *@author Kmud Developer Team
  */

// reminder for me / note to developers: this class must not be an QObject,
// because multiple inheritance of QObject is not allowed. 

class KmudFilter
{

public: 
	KmudFilter();
	virtual ~KmudFilter();

	virtual QString filterInput(QString&);
	virtual QString filterOutput(QString&);

	void setFilterName(QString);

	QString filterName() const;

private:
	QString m_name;
};

#endif

